@@ -40,7 +40,7 @@ class NetcashOrderAdmin(admin.ModelAdmin):
                     'Reason', 'RETC', 'request_ip', 'accepted',
                     'trusted', 'Extra1', 'Extra2', 'Extra3', 'short_debug_info']
     list_filter = ['TransactionAccepted', 'trusted']
-    search_fields = ['Reference']
+    search_fields = ['Reference', 'Extra1', 'Extra2', 'Extra3']
     date_hierarchy = 'created_at'
 
 admin.site.register(NetcashGateway, NetcashGatewayAdmin)
